# Summary

* [Introduction](README.md)
* [Legal Notice](notice.md)
* [Getting Started](getting-started.adoc)
* [Longer Getting Started Guide](book-getting-started.adoc)

* [Architecture](architecture.adoc)
    * [Async](async.adoc)
    * [Asynchronous Routing Engine](asynchronous-routing-engine.adoc)
    * [BacklogDebugger](backlogdebugger.adoc)
    * [BAM](bam.adoc)
    * [Batch Consumer](batch-consumer.adoc)
    * [BrowsableEndpoint](browsable-endpoint.adoc)
    * [Camel Core](camel-core.adoc)
    * [CamelContext](camelcontext.adoc)
    * [CEP](cep.adoc)
    * [Debugger](debugger.adoc)
    * [Delay Interceptor](delay-interceptor.adoc)
    * [Dependency Injection](dependency-injection.adoc)
    * [Dozer Type Conversion](dozer-type-conversion.adoc)
    * [DSL](dsl.adoc)
        * [Java DSL](java-dsl.adoc)
        * [Spring DSL](spring.adoc)
        * [Blueprint DSL](using-osgi-blueprint-with-camel.adoc)
        * [Groovy DSL](groovy-dsl.adoc)
        * [Scala DSL](scala-dsl.adoc)
            * [Scala DSL Getting Started](scala-dsl-getting-started.adoc)
            * [Scala DSL EIP](scala-dsl-eip.adoc)
            * [Scala DSL Supported Languages](scala-dsl-supported-languages.adoc)
        * [Annotation DSL](bean-integration.adoc)
    * [Endpoint](endpoint.adoc)
    * [Error Handler](error-handler.adoc)
    * [Exchange](exchange.adoc)
    * [Exchange Pattern](exchange-pattern.adoc)
    * [Expression](expression.adoc)
    * [Injector](injector.adoc)
    * [Intercept](intercept.adoc)
    * [Inversion Of Control With Smart Defaults](inversion-of-control-with-smart-defaults.adoc)
    * [Lifecycle](lifecycle.adoc)
    * [OnCompletion](oncompletion.adoc)
    * [Registry](registry.adoc)
    * [RX](rx.adoc)
    * [Scala DSL](scala-dsl.adoc)

<!--
    * [Pluggable Class Resolvers](.adoc)
    * [Predicate](.adoc)
    * [Processor](.adoc)
    * [RouteBuilder](.adoc)
    * [RoutePolicy](.adoc)
    * [Routes](.adoc)
    * [ServicePool](.adoc)
    * [Stream caching](.adoc)
    * [ToAsync](.adoc)
    * [Tracer](.adoc)
    * [Transport](.adoc)
    * [Type Converter](.adoc)
    * [URIs](.adoc)
    * [Xml Configuration](.adoc)
    * [ProcessorFactory](.adoc)
    * [Asynchronous Routing Engine](.adoc)
    * [Security](.adoc)
    * [UuidGenerator](.adoc)
    * [Binding](.adoc)
    * [BacklogTracer](.adoc)
    * [Endpoint Annotations](.adoc)
    * [ComponentConfiguration](.adoc)
    * [BacklogDebugger](.adoc)
    * [EndpointCompleter](.adoc)
    * [Clustering and loadbalancing](.adoc)
    * [Threading Model](.adoc)
-->

* [Enterprise Integration Patterns](enterprise-integration-patterns.adoc)
    * [Correlation Identifier](correlation-identifier.adoc)
    * [Event Message](event-message.adoc)
    * [Message](message.adoc)
    * [Message Channel](message-channel.adoc)
    * [Request Reply](request-reply.adoc)
    * [Return Address](return-address.adoc)

* Community
    * FAQ
        * Using Camel questions
            * [How do I configure endpoints](how-do-i-configure-endpoints.adoc)




<!-- core components: START -->
* Core Components
	* [Bean](bean-component.adoc)
	* [Binding](binding-component.adoc)
	* [Browse](browse-component.adoc)
	* [Class](class-component.adoc)
	* [Control Bus](controlbus-component.adoc)
	* [Data Format](dataformat-component.adoc)
	* [Dataset](dataset-component.adoc)
	* [Direct](direct-component.adoc)
	* [Direct VM](direct-vm-component.adoc)
	* [File](file-component.adoc)
	* [Language](language-component.adoc)
	* [Log](log-component.adoc)
	* [Mock](mock-component.adoc)
	* [Properties](properties-component.adoc)
	* [Ref](ref-component.adoc)
	* [REST](rest-component.adoc)
	* [REST API](rest-api-component.adoc)
	* [Scheduler](scheduler-component.adoc)
	* [SEDA](seda-component.adoc)
	* [Stub](stub-component.adoc)
	* [Test](test-component.adoc)
	* [Timer](timer-component.adoc)
	* [Validator](validator-component.adoc)
	* [VM](vm-component.adoc)
	* [XSLT](xslt-component.adoc)
<!-- core components: END -->









<!-- components: START -->
* Components
	* [AHC](ahc-component.adoc)
	* [AHC Websocket](ahc-ws-component.adoc)
	* [AMQP](amqp-component.adoc)
	* [Apache Flink](flink-component.adoc)
	* [Apache Spark](spark-component.adoc)
	* [APNS](apns-component.adoc)
	* [Asterisk](asterisk-component.adoc)
	* [Atmos](atmos-component.adoc)
	* [Atmosphere Websocket](atmosphere-websocket-component.adoc)
	* [Atom](atom-component.adoc)
	* [Avro](avro-component.adoc)
	* [AWS CloudWatch](aws-cw-component.adoc)
	* [AWS DynamoDB](aws-ddb-component.adoc)
	* [AWS DynamoDB Streams](aws-ddbstream-component.adoc)
	* [AWS EC2](aws-ec2-component.adoc)
	* [AWS Kinesis](aws-kinesis-component.adoc)
	* [AWS S3 Storage Service](aws-s3-component.adoc)
	* [AWS Simple Email Service](aws-ses-component.adoc)
	* [AWS Simple Notification System](aws-sns-component.adoc)
	* [AWS Simple Queue Service](aws-sqs-component.adoc)
	* [AWS Simple Workflow](aws-swf-component.adoc)
	* [AWS SimpleDB](aws-sdb-component.adoc)
	* [Bean Validator](bean-validator-component.adoc)
	* [Beanstalk](beanstalk-component.adoc)
	* [Box](box-component.adoc)
	* [Braintree](braintree-component.adoc)
	* [Camel Context](context-component.adoc)
	* [Cassandra CQL](cql-component.adoc)
	* [Chronicle Engine](chronicle-engine-component.adoc)
	* [Chunk](chunk-component.adoc)
	* [CM SMS Gateway](cm-sms-component.adoc)
	* [CMIS](cmis-component.adoc)
	* [CoAP](coap-component.adoc)
	* [CometD](cometd-component.adoc)
	* [Consul](consul-component.adoc)
	* [CouchDB](couchdb-component.adoc)
	* [Crypto (JCE)](crypto-component.adoc)
	* [CXF](cxf-component.adoc)
	* [CXF-RS](cxfrs-component.adoc)
	* [Disruptor](disruptor-component.adoc)
	* [DNS](dns-component.adoc)
	* [Docker](docker-component.adoc)
	* [Dozer](dozer-component.adoc)
	* [Dropbox](dropbox-component.adoc)
	* [EHCache](cache-component.adoc)
	* [Ehcache](ehcache-component.adoc)
	* [EJB](ejb-component.adoc)
	* [Elasticsearch](elasticsearch-component.adoc)
	* [ElSQL](elsql-component.adoc)
	* [etcd](etcd-component.adoc)
	* [Exec](exec-component.adoc)
	* [Facebook](facebook-component.adoc)
	* [Flatpack](flatpack-component.adoc)
	* [FOP](fop-component.adoc)
	* [Freemarker](freemarker-component.adoc)
	* [FTP](ftp-component.adoc)
	* [FTPS](ftps-component.adoc)
	* [Ganglia](ganglia-component.adoc)
	* [Geocoder](geocoder-component.adoc)
	* [Git](git-component.adoc)
	* [GitHub](github-component.adoc)
	* [Google Calendar](google-calendar-component.adoc)
	* [Google Drive](google-drive-component.adoc)
	* [Google Mail](google-mail-component.adoc)
	* [Gora](gora-component.adoc)
	* [Grape](grape-component.adoc)
	* [Guava EventBus](guava-eventbus-component.adoc)
	* [Hazelcast](hazelcast-component.adoc)
	* [HBase](hbase-component.adoc)
	* [HDFS](hdfs-component.adoc)
	* [HDFS2](hdfs2-component.adoc)
	* [Hipchat](hipchat-component.adoc)
	* [HTTP](http-component.adoc)
	* [HTTP4](http4-component.adoc)
	* [iBatis](ibatis-component.adoc)
	* [IMAP](imap-component.adoc)
	* [Infinispan](infinispan-component.adoc)
	* [InfluxDB](influxdb-component.adoc)
	* [IRC](irc-component.adoc)
	* [ironmq](ironmq-component.adoc)
	* [JavaSpace](javaspace-component.adoc)
	* [JBPM](jbpm-component.adoc)
	* [JCache](jcache-component.adoc)
	* [JClouds](jclouds-component.adoc)
	* [JCR](jcr-component.adoc)
	* [JDBC](jdbc-component.adoc)
	* [Jetty 9](jetty-component.adoc)
	* [Jetty Websocket](websocket-component.adoc)
	* [JGroups](jgroups-component.adoc)
	* [Jing](jing-component.adoc)
	* [JIRA](jira-component.adoc)
	* [JMS](jms-component.adoc)
	* [JMX](jmx-component.adoc)
	* [JOLT](jolt-component.adoc)
	* [JPA](jpa-component.adoc)
	* [JT400](jt400-component.adoc)
	* [Kafka](kafka-component.adoc)
	* [Kestrel](kestrel-component.adoc)
	* [Krati](krati-component.adoc)
	* [Kubernetes](kubernetes-component.adoc)
	* [LDAP](ldap-component.adoc)
	* [Linkedin](linkedin-component.adoc)
	* [Lucene](lucene-component.adoc)
	* [Lumberjack](lumberjack-component.adoc)
	* [Metrics](metrics-component.adoc)
	* [Mina](mina-component.adoc)
	* [Mina2](mina2-component.adoc)
	* [MLLP](mllp-component.adoc)
	* [MongoDB](mongodb-component.adoc)
	* [MongoDBGridFS](gridfs-component.adoc)
	* [MQTT](mqtt-component.adoc)
	* [MSV](msv-component.adoc)
	* [Mustache](mustache-component.adoc)
	* [MVEL](mvel-component.adoc)
	* [MyBatis](mybatis-component.adoc)
	* [Nagios](nagios-component.adoc)
	* [Nats](nats-component.adoc)
	* [Netty](netty-component.adoc)
	* [Netty HTTP](netty-http-component.adoc)
	* [Netty4](netty4-component.adoc)
	* [Netty4 HTTP](netty4-http-component.adoc)
	* [OpenShift](openshift-component.adoc)
	* [OptaPlanner](optaplanner-component.adoc)
	* [OSGi EventAdmin](eventadmin-component.adoc)
	* [OSGi PAX Logging](paxlogging-component.adoc)
	* [Paho](paho-component.adoc)
	* [PDF](pdf-component.adoc)
	* [PostgresSQL Event](pgevent-component.adoc)
	* [Printer](lpr-component.adoc)
	* [Quartz](quartz-component.adoc)
	* [Quartz2](quartz2-component.adoc)
	* [QuickFix](quickfix-component.adoc)
	* [RabbitMQ](rabbitmq-component.adoc)
	* [Restlet](restlet-component.adoc)
	* [RMI](rmi-component.adoc)
	* [RouteBox](routebox-component.adoc)
	* [RSS](rss-component.adoc)
	* [Salesforce](salesforce-component.adoc)
	* [SAP NetWeaver](sap-netweaver-component.adoc)
	* [Schematron](schematron-component.adoc)
	* [SCP](scp-component.adoc)
	* [ServiceNow](servicenow-component.adoc)
	* [Servlet](servlet-component.adoc)
	* [SFTP](sftp-component.adoc)
	* [Simple JMS](sjms-component.adoc)
	* [Simple JMS Batch](sjms-batch-component.adoc)
	* [SIP](sip-component.adoc)
	* [Slack](slack-component.adoc)
	* [SMPP](smpp-component.adoc)
	* [SNMP](snmp-component.adoc)
	* [Solr](solr-component.adoc)
	* [Spark Rest](spark-rest-component.adoc)
	* [Splunk](splunk-component.adoc)
	* [Spring Batch](spring-batch-component.adoc)
	* [Spring Event](spring-event-component.adoc)
	* [Spring Integration](spring-integration-component.adoc)
	* [Spring LDAP](spring-ldap-component.adoc)
	* [Spring Redis](spring-redis-component.adoc)
	* [Spring WebService](spring-ws-component.adoc)
	* [SQL](sql-component.adoc)
	* [SQL Stored Procedure](sql-stored-component.adoc)
	* [SSH](ssh-component.adoc)
	* [StAX](stax-component.adoc)
	* [Stomp](stomp-component.adoc)
	* [Stream](stream-component.adoc)
	* [String Template](string-template-component.adoc)
	* [Telegram](telegram-component.adoc)
	* [Twitter](twitter-component.adoc)
	* [Undertow](undertow-component.adoc)
	* [Velocity](velocity-component.adoc)
	* [Vert.x](vertx-component.adoc)
	* [Weather](weather-component.adoc)
	* [XML RPC](xmlrpc-component.adoc)
	* [XML Security](xmlsecurity-component.adoc)
	* [XMPP](xmpp-component.adoc)
	* [XQuery](xquery-component.adoc)
	* [Yammer](yammer-component.adoc)
	* [ZooKeeper](zookeeper-component.adoc)
<!-- components: END -->





* Other Components
  * [BAM (Business Activity Monitoring)](bam.adoc)
  * [CDI](cdi.adoc)
  * [Eclipse](eclipse.adoc)
  * [Grape](grape.adoc)
  * [Guice](guice.adoc)
  * [HawtDB](hawtdb.adoc)
  * [Hystrix](hystrix.adoc)
  * [LevelDB](leveldb.adoc)
  * [Jasypt](jasypt.adoc)
  * [Kura](kura.adoc)
  * [Ribbon](ribbon.adoc)
  * [RX](rx.adoc)
  * [SCR](scr.adoc)
  * [Shiro](shiro.adoc)
  * [Swagger Java](swagger-java.adoc)
  * [Zipkin](zipkin.adoc)



<!-- dataformats: START -->
* Data Formats
	* [Avro](avro-dataformat.adoc)
	* [Barcode](barcode-dataformat.adoc)
	* [Base64](base64-dataformat.adoc)
	* [BeanIO](beanio-dataformat.adoc)
	* [Bindy CSV](bindy-dataformat.adoc)
	* [Bindy Fixed Length](bindy-dataformat.adoc)
	* [Bindy Key Value Pair](bindy-dataformat.adoc)
	* [Boon](boon-dataformat.adoc)
	* [Castor](castor-dataformat.adoc)
	* [Crypto (Java Cryptographic Extension)](crypto-dataformat.adoc)
	* [CSV](csv-dataformat.adoc)
	* [Flatpack](flatpack-dataformat.adoc)
	* [GZip](gzip-dataformat.adoc)
	* [Hessian](hessian-dataformat.adoc)
	* [HL7](hl7-dataformat.adoc)
	* [iCal](ical-dataformat.adoc)
	* [JacksonXML](jacksonxml-dataformat.adoc)
	* [Java Object Serialization](serialization-dataformat.adoc)
	* [JAXB](jaxb-dataformat.adoc)
	* [JiBX](jibx-dataformat.adoc)
	* [JSon GSon](json-gson-dataformat.adoc)
	* [JSon Jackson](json-jackson-dataformat.adoc)
	* [JSon Johnzon](json-johnzon-dataformat.adoc)
	* [JSon XStream](json-xstream-dataformat.adoc)
	* [LZF Deflate Compression](lzf-dataformat.adoc)
	* [MIME Multipart](mime-multipart-dataformat.adoc)
	* [PGP](pgp-dataformat.adoc)
	* [Protobuf](protobuf-dataformat.adoc)
	* [RSS](rss-dataformat.adoc)
	* [SOAP](soapjaxb-dataformat.adoc)
	* [String Encoding](string-dataformat.adoc)
	* [Syslog](syslog-dataformat.adoc)
	* [Tar File](tarfile-dataformat.adoc)
	* [TidyMarkup](tidyMarkup-dataformat.adoc)
	* [uniVocity CSV](univocity-csv-dataformat.adoc)
	* [uniVocity Fixed Length](univocity-fixed-dataformat.adoc)
	* [uniVocity TSV](univocity-tsv-dataformat.adoc)
	* [XML Beans](xmlBeans-dataformat.adoc)
	* [XML JSon](xmljson-dataformat.adoc)
	* [XML RPC](xmlrpc-dataformat.adoc)
	* [XML Security](secureXML-dataformat.adoc)
	* [XStream](xstream-dataformat.adoc)
	* [YAML SnakeYAML](yaml-snakeyaml-dataformat.adoc)
	* [Zip Deflate Compression](zip-dataformat.adoc)
	* [Zip File](zipfile-dataformat.adoc)
<!-- dataformats: END -->









<!-- languages: START -->
* Expression Languages
	* [Bean method](bean-language.adoc)
	* [Constant](constant-language.adoc)
	* [EL](el-language.adoc)
	* [ExchangeProperty](exchangeProperty-language.adoc)
	* [File](file-language.adoc)
	* [Groovy](groovy-language.adoc)
	* [Header](header-language.adoc)
	* [HL7 Terser](terser-language.adoc)
	* [JavaScript](javaScript-language.adoc)
	* [JSonPath](jsonpath-language.adoc)
	* [JXPath](jxpath-language.adoc)
	* [MVEL](mvel-language.adoc)
	* [OGNL](ognl-language.adoc)
	* [PHP](php-language.adoc)
	* [Python](python-language.adoc)
	* [Ref](ref-language.adoc)
	* [Ruby](ruby-language.adoc)
	* [Simple](simple-language.adoc)
	* [SpEL](spel-language.adoc)
	* [SQL](sql-language.adoc)
	* [Tokenize](tokenize-language.adoc)
	* [XML Tokenize](xtokenize-language.adoc)
	* [XPath](xpath-language.adoc)
	* [XQuery](xquery-language.adoc)
<!-- languages: END -->




* Example
    * [BAM Example](bam-example.adoc)

* User Guide
    * [Karaf](karaf.adoc)
    * [Testing](testing.adoc)
        * [Test](test.adoc)
        * [Blueprint Testing](test-blueprint.adoc)
        * [CDI Testing](cdi-testing.adoc)
        * [Spring Testing](spring-testing.adoc)
    * [JSSE Utility](camel-configuration-utilities.adoc)

* Developer Guide
    * [Building](building.adoc)
